#! /usr/bin/env ruby
# -*- coding: utf-8 -*-
# 
# 現在の統計ページをもとにしてリソースファイル <tt>resource.xml</tt> のlanguage要素を
# ファイルに出力します。
# 出力ファイルの名前は、<tt>resource-languages.xml</tt> です。
# ファイル出力が正常に行われた場合、終了ステータス 0 を返します。
# なんらかの原因で正常に行われなかった場合、終了ステータスとして 0 以外を返します。
# 

require './languages-statistics'

$stderr.puts 'Console encoding set in config.xml: ' + WikiBotConfig.new.console_encoding
processor = LanguageResourcePrinter.new
processor.execute
exit(processor.status)

